#include <stdio.h>
#include <string.h>
#include <iostream>
#include <vector>
#include <algorithm>
#include <cstdlib>

using namespace std;

void gen(const vector<int> &prob, int s, int i, vector<int> *out) {
  int r = random() % 100;
  if (s == 1 || r < prob[i]) out->push_back(s);
  else {
    gen(prob, s/2, i+1, out);
    gen(prob, s/2, i+1, out);
  }
}

void shuffle(const vector<int> &in, vector<int> *out) {
  int M = *max_element(in.begin(), in.end());
  vector<int> pp;
  for (int i = 0; i < in.size(); ++i) {
    if (in[i] == M) pp.push_back(i);
  }
  int first = pp[random() % pp.size()];
  out->push_back(in[first]);
  int last = first + 1;
  while (first > 0 || last < in.size()) {
    if (first == 0) {
      out->push_back(in[last++]);
    }
    else if (last == in.size()) {
      out->push_back(in[--first]);
    }
    else if (random()%100<50) {
      out->push_back(in[last++]);
    }
    else {
      out->push_back(in[--first]);
    }
  }
}

void gen(const vector<int> &prob, vector<int> *out) {
  int s = 1 << prob.size();
  vector<int> tmp;
  gen(prob, 1 << prob.size(), 0, &tmp);
  shuffle(tmp, out);
}

struct state {
  int left, right;  // left != 0
  state() : left(0), right(0) {}
  void extend(int next_val, vector<state> *output) const;
  void rotate();
  bool can_extend_left(int number) const;
  void extend_left(int number);
  bool is_final() const;
};

int largest_power(int v) {
  v |= (v >> 1);
  v |= (v >> 2);
  v |= (v >> 4);
  v |= (v >> 8);
  return v - (v >> 1);
}

void state::rotate() {
  swap(left, right);
  if (left < right) {
    int p = largest_power(right);
    right -= p;
    left += p;
  }
}

bool state::can_extend_left(int number) const {
  if (!(left & (number - 1))) return true;
  if (left > right && number > left && left == largest_power(left)) return true;
  return false; 
}

void state::extend_left(int number) {
  if (number > left) {
    right += left;
    left = number;
  } else {
    left += number;
  }
}

bool state::is_final() const {
  return right == 0 && left == largest_power(left);
}

void state::extend(int next_val, vector<state> *output) const {
  state next = *this;
  if (next.can_extend_left(next_val)) {
    next.extend_left(next_val);
    output->push_back(next);
  }
  next = *this;
  next.rotate();
  if (next.can_extend_left(next_val)) {
    next.extend_left(next_val);
    next.rotate();
    output->push_back(next);
  }
}

bool operator<(const state &a, const state &b) {
  if (a.left != b.left) return a.left < b.left;
  else return a.right < b.right;
}

bool state_equal(const state &a, const state &b) {
  return a.left == b.left && a.right == b.right;
}

void alg(const vector<state> &in, int next_val, vector<state> *out) {
  out->clear();
  for (int j = 0; j < in.size(); ++j) in[j].extend(next_val, out);
  sort(out->begin(), out->end());
  out->resize(unique(out->begin(), out->end(), state_equal) - out->begin());
}

int count_bits(int v) {
  int r = 0;
  while (v > 0) {
    r += (v & 1);
    v >>= 1;
  }
  return r;
}

int get_valid_next(int max_power, int total, const vector<state> &in, bool increase, bool finalize, vector<state> *res) {
  int sum = 0;
  if (!in.empty()) {
    sum = in[0].left + in[0].right;
  }
  if (total - sum <= 0) return -1;
  int max_val = largest_power(total - sum);
  if (max_val > max_power) max_val = max_power;
  vector<vector<state> > next;
  vector<int> next_val;
  int mask = 0;
  for (int i = 0; i < in.size(); ++i) {
    if (in[i].left)
      mask |= in[i].left ^ (in[i].left & (in[i].left-1));
    if (in[i].right)
      mask |= in[i].right ^ (in[i].right & (in[i].right-1));
  }
  for (int i = 1; i <= max_val; i += i) {
    if (finalize && !(mask & i)) continue;
    next.push_back(vector<state>());
    next_val.push_back(i);
    vector<state> &n1 = next.back();
    alg(in, i, &n1);
  }
  
  vector<int> good_states;
  if (finalize) {
    max_val = largest_power(total - sum);
    vector<pair<pair<int, int>, int> > tmp;
    for (int i = 0; i < next.size(); ++i) {
      int m = -1, s = 0;
      for (int j = 0; j < next[i].size(); ++j) {
        int x = count_bits(next[i][j].left) + count_bits(next[i][j].right);
        m = max(x, m);
        s += x;
      }
      tmp.push_back(make_pair(make_pair(m, s), i));
    }
    sort(tmp.begin(), tmp.end());
    if (tmp.empty()) return -1;
    good_states.push_back(tmp[0].second);
  } else if (increase) {
    for (int i = 0; i < next.size(); ++i) {
      if (next[i].size() > in.size()) good_states.push_back(i);
    }
    if (good_states.empty()) {
      for (int i = 0; i < next.size(); ++i) {
        if (next[i].size() <= in.size() && !next[i].empty()) good_states.push_back(i);
      }
    }
  } else {
    for (int i = 0; i < next.size(); ++i) {
      if (next[i].size() <= in.size() && !next[i].empty()) good_states.push_back(i);
    }
    if (good_states.empty()) {
      for (int i = 0; i < next.size(); ++i) {
      if (next[i].size() > in.size()) good_states.push_back(i);
    }
    }
  }
  res->clear();
  if (good_states.empty()) return -1;
  int result_idx = good_states[random() % good_states.size()];
  *res = next[result_idx];
  return next_val[result_idx];
}

void gen2(const vector<int> &params, vector<int> *out) {
  int total = params[1]; // -1 indicates gen2 is to be used
  vector<state> current;
  current.push_back(state());
  current.front().left = 1;
  current.front().right = 0;
  out->push_back(1);
  for (int k = 2; k+1 < params.size(); k+=2) {
    int p = params[k];
    int max_power = params[k+1];
    if (p >= 0) {
      while (p--) {
        vector<state> next;
        int v = get_valid_next(max_power, total/2, current, true, false, &next);
        if (v == -1) break;
        out->push_back(v);
        current.swap(next);
        //clog << "#+ " << current.size() << endl;
      }
    } else {
      while (p++) {
        vector<state> next;
        int v = get_valid_next(max_power, total/2, current, false, false, &next);
        if (v == -1) break;
        out->push_back(v);
        current.swap(next);
        //clog << "#- " << current.size() << endl;
      }
    }
  }
  while (current.size() > 1 || current.size() == 1 && count_bits(current[0].left) + count_bits(current[0].right) > 1) {
    vector<state> next;
    int v = get_valid_next(1<<13, total, current, false, true, &next);
    if (v == -1) break;
    out->push_back(v);
    current.swap(next);
    //clog << "#* " << current.size() << endl;
  }
  //clog << "#." << endl;
}

int main() {
  vector<vector<int> > probs;
  vector<int> times;
  int n;
  cin >> n;
  for (int i = 0; i < n; ++i){
    int k, t;
    cin >> k >> t;
    probs.push_back(vector<int>());
    times.push_back(t);
    while (k--) {
      int z;
      cin >> z;
      probs[i].push_back(z);
    }
  }
  int T = 0;
  for (int i = 0; i < times.size(); ++i) {
    T += times[i];
  }
  cout << T << endl;
  for (int i = 0; i < times.size(); ++i) {
    for (int j = 0; j < times[i]; ++j) {
      vector<int> tmp;
      if (probs[i].size() > 0 && probs[i][0] == -1) {
        gen2(probs[i], &tmp);
      }
      else {
        gen(probs[i], &tmp);
      }
      cout << tmp.size() << endl;
      for (int i = 0; i < tmp.size(); ++i) {
        if (i) cout << ' ';
        cout << tmp[i];
      }
      cout << endl;
    }
  }
}
