// Author: Lech Duraj
// O(n log^2 n)

#include <cstdio>
#include <algorithm>
#include <vector>
#include <cassert>

using namespace std;

typedef pair<int,int> PI;
typedef long long LL;

bool turnleft(PI a, PI b, PI c)
{
    LL ux = b.first - a.first;
    LL uy = b.second - a.second;
    LL vx = c.first - a.first;
    LL vy = c.second - a.second;
    return (ux*vy - uy*vx > 0);
}

LL val(PI u, PI v, PI z)
{
    LL A = u.second-v.second;
    LL B = v.first-u.first;
    LL C = A*u.first + B*u.second;
    assert(A*v.first + B*v.second == C);
    return A*z.first + B*z.second - C;
}

bool crossing(PI x, PI y, vector<PI> &H)
{
    int p=0; 
    int q=H.size()-1;
    while(p+6<q)
    {
        int r = (q-p+2)/3;
        LL a = val(x, y, H[p+r]);
        LL b = val(x, y, H[q-r]);
        if (a>b)
            q = q-r;
        else
            p = p+r;
    }
    for(int i=p; i<=q; i++)
        if (val(x,y,H[i])>0)
            return true;
    return false;
}

void merge(vector<PI> &X, vector<PI> &Y, vector<PI> &C)
{
    vector<PI> A = X;
    vector<PI> B = Y;
    int i = A.size()-1;
    int j = 0;
    while (     (i>0 && turnleft(A[i-1],A[i],B[j])) ||
                (j<B.size()-1 && turnleft(A[i],B[j],B[j+1]))      )
    {
        if (i>0 && turnleft(A[i-1],A[i],B[j]))
            i--;
        if (j<B.size()-1 && turnleft(A[i],B[j],B[j+1]))      
            j++;
    }
    C.insert(C.end(),A.begin(),A.begin()+i+1);
    C.insert(C.end(),B.begin()+j,B.end());
}

int main()
{
    int TT;
    scanf("%d",&TT);
    while(TT--)
    {
        int n;
        scanf("%d",&n);
        int L = 0;
        while((1 << L) < n)
            L++;
        int M = 1 << L;
        vector<PI> points(M);
        vector< vector<PI> > hulls(2*M);
        for(int i=0; i<n; i++)
            scanf("%d%d",&points[i].first,&points[i].second);
        for(int i=n; i<M; i++)
            points[i] = PI(points[i-1].first+1,points[i].second);
        for(int i=0; i<M; i++)
            hulls[M+i].push_back(points[i]);
        for(int i=M-1; i>=1; i--)
            merge(hulls[2*i],hulls[2*i+1],hulls[i]);
        for(int j=0; j+1<n; j++)
        {
            int node = 1;
            int len = M;
            int where = M-1;
            int last = 2*M+1;
            while(where>j+1)
            {
                if (where-len>=j+1)
                {
                    if (crossing(points[j],points[j+1],hulls[node]))
                        last = node;
                    where -= len;
                    node--;
                }
                len /= 2;
                node = 2*node+1;
            }
            node = last;
            assert(last>2*M || crossing(points[j],points[j+1],hulls[node]));
            while(node<M)
            {
                if (crossing(points[j],points[j+1],hulls[2*node]))
                    node = 2*node;
                else
                    node = 2*node+1;
            }
            if (node-M>=n)
                printf(j==0 ? "0": " 0");
            else
                printf(j==0 ? "%d": " %d",node-M);
        }
        printf("\n");
    }
}
