import java.io.*;
import java.util.*;
import java.math.*;

public class D implements Runnable {
	private static BufferedReader in;
	private static StringTokenizer st;
	private static PrintWriter out;

	static class Fraction {
		BigInteger top, bottom;

		public Fraction() {
			this.top = BigInteger.ONE;
			this.bottom = BigInteger.ONE;
		}

		public Fraction(int top, int bottom) {
			this.top = BigInteger.valueOf(top);
			this.bottom = BigInteger.valueOf(bottom);
		}

		public Fraction(BigInteger top, BigInteger bottom) {
			this.top = top;
			this.bottom = bottom;
		}

		public void simplify() {
			BigInteger gcd = top.gcd(bottom);
			top = top.divide(gcd);
			bottom = bottom.divide(gcd);
		}

		public static Fraction multiply(Fraction a, Fraction b) {
			BigInteger newTop = a.top.multiply(b.top);
			BigInteger newBottom = b.bottom.multiply(a.bottom);
			Fraction result = new Fraction(newTop, newBottom);
			result.simplify();
			return result;
		}

		@Override
		public String toString() {
			if (bottom.equals(BigInteger.ONE))
				return top.toString();
			else
				return top.toString() + "/" + bottom.toString();
		}
	}

	private void solveOne() throws IOException {
		int n = nextInt();
		int[] xs = new int[n], ys = new int[n], rs = new int[n];
		for (int i = 0; i < n; i++) {
			xs[i] = nextInt();
			ys[i] = nextInt();
			rs[i] = nextInt();
		}
		Fraction[] results = new Fraction[n];
		boolean[] color = new boolean[n];
		results[0] = new Fraction();
		Queue<Integer> q = new ArrayDeque<>();
		q.add(0);
		while (!q.isEmpty()) {
			int u = q.poll();
			for (int v = 0; v < n; v++) {
				if (results[v] == null && isConnected(xs, ys, rs, u, v)) {
					results[v] = Fraction.multiply(results[u], new Fraction(
							rs[u], rs[v]));
					color[v] = !color[u];
					q.add(v);
				}
			}
		}
		for (int i = 0; i < n; i++) {
			Fraction currentFraction = results[i];
			if (currentFraction == null) {
				out.println("not moving");
			} else {
				out.println(currentFraction + " "
						+ (!color[i] ? "clockwise" : "counterclockwise"));
			}
		}
	}

	private boolean isConnected(int[] xs, int[] ys, int[] rs, int u, int v) {
		long dx = xs[u] - xs[v];
		long dy = ys[u] - ys[v];
		double distance = Math.sqrt(dx * dx + dy * dy);
		double needDistance = rs[u] + rs[v];
		return Math.abs(distance - needDistance) < 1e-9;
	}

	private void solve() throws IOException {
		int tests = nextInt();
		for (int test = 0; test < tests; test++)
			solveOne();
	}

	public void run() {
		final String className = this.getClass().getName().toLowerCase();

		try {
			try {
				in = new BufferedReader(new FileReader(className + ".in"));
				out = new PrintWriter(new FileWriter(className + ".out"));
			} catch (FileNotFoundException e) {
				in = new BufferedReader(new InputStreamReader(System.in));
				out = new PrintWriter(System.out);
			}

			solve();

			out.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	public static void main(String[] args) {
		new D().run();
		// new Thread(null, new Template(), "Template", (1L << 24)).start();
	}

	private String nextToken() throws IOException {
		while (st == null || !st.hasMoreTokens()) {
			String line = in.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}

	private int nextInt() throws IOException {
		return Integer.parseInt(nextToken());
	}

	private long nextLong() throws IOException {
		return Long.parseLong(nextToken());
	}

	private double nextDouble() throws IOException {
		return Double.parseDouble(nextToken());
	}

}
