#include <iostream>
#include <iomanip>
#include <algorithm>
#include <cstring>
#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <vector>
#include <string>
#include <map>
#include <set>
#include <queue>
#include <stack>

using namespace std;

const int MAX_N = 150005;
const int MAX_V = 1000005;

struct SegmentTree {
    int offset;
    vector< int > v;

    void initialize(int n) {
        for (offset = 1; offset < n; offset <<= 1)
            ;

        v.clear();
        v.resize(2 * offset, 1);

        for (int i = offset - 1; i >= 0; i--) {
            v[i] = v[i * 2] + v[i * 2 + 1];
        }
    }

    void update(int x, int val) {
        v[x + offset] = val;

        for (int i = (x + offset) >> 1; i > 0; i >>= 1) {
            v[i] = v[i * 2] + v[i * 2 + 1];
        }
    }

    int query(int x = 1) {
        if (x >= offset) {
            return x - offset;
        }

        if (v[x * 2]) {
            return query(x * 2);
        }

        return query(x * 2 + 1);
    }
};

int n, k;
pair< int, int > vc[MAX_N], vmc[MAX_N];
SegmentTree t;

bool possible(int val) {
    t.initialize(n);

    int d;

    for (d = 0; d < n && vmc[d].first < val; d++) {
        t.update(vmc[d].second, 0);
    }

    if (d == n) {
        return false;
    }

    int c = 0;

    for (int i = 0; i < k + 1; i++) {
        while (d < n && vmc[d].first - c < val) {
            t.update(vmc[d].second, 0);
            d++;
        }

        if (d == n) {
            return false;
        }

        int q = t.query();

        if (q >= n) {
            return false;
        }

        t.update(q, 0);

        c += vc[q].first;
    }

    return true;
}

int main() {
    int tests;

    scanf("%d", &tests);

    for (int test = 0; test < tests; test++) {
        scanf("%d %d", &n, &k);

        int b = 0;

        for (int i = 0; i < n; i++) {
            scanf("%d %d", &vc[i].second, &vc[i].first);
        }

        sort(vc, vc + n);

        for (int i = 0; i < n; i++) {
            vmc[i] = make_pair(vc[i].second - vc[i].first, i);
        }

        sort(vmc, vmc + n);

        int lo = 0, hi = MAX_V; 

        while (lo < hi - 1) {
            int mid = (lo + hi) / 2;

            if (possible(mid)) {
                lo = mid;
            } else {
                hi = mid;
            }
        }

        printf("%d\n", lo);
    }

    return 0;
}
