#include <iostream> 
#include <cstdio> 
#include <map> 
#include <set> 
#include <algorithm> 
#include <cstdlib> 
#include <cstring>
#include <cassert>
#include <utility>
#include <vector>
#include <string>
#include <queue>
#include <fstream> 
#include <iomanip> 
#include <sstream> 
#include <cmath> 
#include <ctime> 
#include <cctype> 
#include <deque> 
#include <numeric>

#define pb push_back
#define mp make_pair

using namespace std;

typedef long long ll;
typedef unsigned long long ull;
typedef long double ld;
typedef pair< int, int > pii;
typedef vector< int > vi;

template <class T> inline void updMax(T &x, const T &other) { if (x < other) x = other; }
template <class T> inline void updMin(T &x, const T &other) { if (other < x) x = other; }
template <class T> inline T sqr(const T &x) { return x * x; } 

const int MAXN = 1111;

struct DSU
{
	int par[MAXN];
	int rnk[MAXN];
	int oldRnk[MAXN];
	vector< pair< int, int > > rollb;
	int getPar(int x)
	{
		return (x == par[x]) ? par[x] : getPar(par[x]);
	}
	void link(int x, int y)
	{
		if (rnk[x] >= rnk[y]) {
			oldRnk[y] = rnk[x];
			par[y] = x;
		} else {
			oldRnk[x] = rnk[y];
			par[x] = y;
		}
		if (rnk[x] == rnk[y]) ++rnk[x];
		rollb.push_back(make_pair(x, y));
	}
	void rollback()
	{
		pair< int, int > lastQ = rollb.back();
		rollb.pop_back();
		int x = lastQ.first, y = lastQ.second;
		if (par[x] == y) {
			par[x] = x;
			rnk[y] = oldRnk[x];
			oldRnk[x] = 0;
		} else {
			par[y] = y;
			rnk[x] = oldRnk[y];
			oldRnk[y] = 0;
		}
	}
	void init(int cnt)
	{
		for (int i = 1; i <= cnt; ++i) {
			par[i] = i;
			rnk[i] = 0;
		}
		rollb.clear();
	}
	bool connected(int x, int y)
	{
		return getPar(x) == getPar(y);
	}
	void insert(int x, int y)
	{
		x = getPar(x);
		y = getPar(y);
		if (x != y) {
			link(x, y);
		}
	}
};

const int MAXM = 100500;

DSU all[MAXN];
int n, m;
vector< pair< ll, pii > > edges;
int f[MAXN], w[MAXN];

struct Tree
{
	vector< int > f;
	vector< ll > w;
	vector< ll > sum;
	Tree *l, *r;
	Tree()
	{
		l = r = NULL;
	}
	void accum()
	{
		sum.assign(w.size(), 0ll);
		partial_sum(w.begin(), w.end(), sum.begin());
	}
	ll
	getSum(int l0, int r0, int l1, int r1, int val)
	{
		ll res = 0ll;
		if (max(l0, l1) < min(r0, r1)) {
			if (l0 <= l1 && r0 >= r1) {
				int cnt = upper_bound(f.begin(), f.end(), val) - f.begin() - 1;
				if (cnt >= 0) {
					res = sum[cnt];
				}
			} else {
				int mid = (l1 + r1) / 2;
				res = l->getSum(l0, r0, l1, mid, val) + r->getSum(l0, r0, mid, r1, val);
			}
		}
		return res;
	}
};

Tree *
construct(int l, int r, const vector< int > &f, const vector< ll > &w)
{
	Tree *res = new Tree();
	if (l == r - 1) {
		res->f.push_back(f[l]);
		res->w.push_back(w[l]);
	} else {
		int mid = (l + r) / 2;
		res->l = construct(l, mid, f, w);
		res->r = construct(mid, r, f, w);
		int q = 0, p = 0;
		const vector< int > &f1 = res->l->f;
		const vector< int > &f2 = res->r->f;
		const vector< ll > &w1 = res->l->w;
		const vector< ll > &w2 = res->r->w;
		while (p + l < mid|| q + mid < r) {
			if (p + l < mid && (q + mid == r || f1[p] < f2[q])) {
				res->f.push_back(f1[p]);
				res->w.push_back(w1[p]);
				p++;
			} else {
				res->f.push_back(f2[q]);
				res->w.push_back(w2[q]);
				++q;
			}
		}
	}
	res->accum();
	return res;
}

void process()
{
	scanf("%d%d", &n, &m);
	edges.clear();
	int lenK = max(int(sqrt(m + 1.)) * 2, 10);
	int k = (m + lenK - 1) / lenK;
	for (int i = 0; i <= k; ++i) {
		all[i].init(n);
	}
	for (int i = 0; i < m; ++i) {
		int x, y;
		ll w;
		scanf("%d%d%lld", &x, &y, &w);
		edges.push_back(make_pair(w, make_pair(x, y)));
	}
	sort(edges.begin(), edges.end());
	for (int curDsu = 0; curDsu < k; ++curDsu) {
		int lPos = curDsu * lenK, rPos = min(m, lenK * (curDsu + 1));
		for (int curE = lPos; curE < rPos; ++curE) {
			w[curE] = edges[curE].first;
			int x = edges[curE].second.first, y = edges[curE].second.second;
			int curId = curDsu + 1;
			while (curId >= 0 && !all[curId].connected(x, y)) {
				--curId;
			}
			curId++;
			if (curId == 0) {
				f[curE] = 0;
			} else {
				int addE = min(curE, curId * lenK);
				int cnt = 0;
				while (!all[curId].connected(x, y)) {
					--addE;
					all[curId].insert(edges[addE].second.first, edges[addE].second.second);
					++cnt;
				}
				f[curE] = addE + 1;
				for (int i = 0; i < cnt; ++i) {
					all[curId].rollback();
				}
			}
			for (int curId = 0; curId <= curDsu; ++curId) {
				all[curId].insert(x, y);
			}
		}
	}
	ll curAns = 0ll;
	/*for (int i = 0; i < m; ++i) {
		printf("(%d, %d) w = %d, f = %d\n", edges[i].second.first, edges[i].second.second, w[i], f[i] + 1);
	}*/
	Tree *root = construct(0, m, vector< int >(f, f + m), vector< ll >(w, w + m));
	vector< ll > allW;
	for (int i = 0; i < m; ++i) {
		allW.push_back(edges[i].first);
	}
	int q;
	scanf("%d", &q);
	for (int i = 0; i < q; ++i) {
		ll l, h;
		scanf("%lld%lld", &l, &h);
		l -= curAns, h -= curAns;
		int lPos = lower_bound(allW.begin(), allW.end(), l) - allW.begin();
		int rPos = upper_bound(allW.begin(), allW.end(), h) - allW.begin();
		//printf("lPos = %d, rPos = %d\n", lPos, rPos);
		curAns = 0ll;
		if (lPos < rPos) {
			curAns = root->getSum(lPos, rPos, 0, m, lPos);
		}
		printf("%lld\n", curAns);
	}
}

int main()
{
	//freopen("input.txt", "r", stdin); freopen("output.txt", "w", stdout);
	//freopen(".in", "r", stdin); freopen(".out", "w", stdout);
	
	//ios::sync_with_stdio(false); 

	int t;
	scanf("%d", &t);
	for (int i = 0; i < t; ++i) {
		process();
	}

	return 0;
}